@@ -484,28 +484,14 @@ HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, H
 
 
 class DataTransformerForm(BaseInlineFormSet):
-    id = forms.CharField(required=False,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    accessory = forms.CharField(required=False,
-                                widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-
-    data_transformer_parent = forms.CharField(required=False,
-                                              widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    type = forms.CharField(required=True,
-                           widget=forms.TextInput(attrs={'class': 'form-control'}))
-
-    def __init__(self, *args, **kwargs):
-        self.DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-                                                                  fk_name='data_transformer_parent',
-                                                                  extra=1, exclude=['updated_at', 'created_at'],
-                                                                  form=self.__class__)
-
-        super(DataTransformerForm, self).__init__(*args, **kwargs)
 
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
-
-        form.nested_data_transformer_form = self.DataTransformerInlineFormset(
+        dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                             fk_name='data_transformer_parent',
+                                                             extra=1, exclude=['updated_at', 'created_at'],
+                                                             form=self.__class__)
+        form.nested_data_transformer_form = dataTransformerInlineFormset(
             instance=self.instance.datatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
@@ -529,6 +515,19 @@ class DataTransformerForm(BaseInlineFormSet):
             files=self.files if self.is_bound else None,
             extra=1)
 
+
+class DataTransform(forms.Form):
+    id = forms.CharField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    accessory = forms.CharField(required=False,
+                                widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+
+    data_transformer_parent = forms.CharField(required=False,
+                                              widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    type = forms.CharField(required=True,
+                           widget=forms.TextInput(attrs={'class': 'form-control'}))
+
+
     class Meta:
         model = DataTransformer
         fields = ("__all__")
