@@ -1,6 +1,7 @@
 import json
 
 from django.core import serializers as django_serializers
+from django.forms import formset_factory
 from django.http import JsonResponse, HttpResponse, QueryDict
 from django.shortcuts import render, get_object_or_404
 from django.utils.decorators import method_decorator
@@ -360,7 +361,7 @@ class HardwareViewSet(viewsets.ModelViewSet):
                 hardware.get_real_concrete_instance_class().delete()
             return HttpResponse(render(request, 'hardwares.html'))
 
-from data.forms.forms import DataTransformerForm
+from data.forms.forms import DataTransformerForm,DataTransform
 from data.models.models import DataTransformer
 
 class AccessoryViewSet(viewsets.ModelViewSet):
@@ -387,12 +388,14 @@ class AccessoryViewSet(viewsets.ModelViewSet):
 
         if accessory.has_data_transformer:
             data_transformer = accessory.datatransformer
-            formset = DataTransformerForm(instance=data_transformer)
+            datatransformerset = formset_factory(DataTransform, formset=DataTransformerForm, extra=1)
+            formset = datatransformerset(initial=[data_transformer])
         else:
             data_transformer = DataTransformer()
             data_transformer.accessory = accessory
             data_transformer.save()
-            formset = DataTransformerForm(instance=data_transformer)
+            datatransformerset = formset_factory(DataTransform, formset=DataTransformerForm, extra=1)
+            formset = datatransformerset(initial=[])
 
 
 
